package com.ruoyi.project.plant.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.plant.mapper.TConfInfoMapper;
import com.ruoyi.project.plant.domain.TConfInfo;
import com.ruoyi.project.plant.service.ITConfInfoService;

/**
 * 会议预约信息Service业务层处理
 *
 * @author ssy
 * @date 2024-05-06
 */
@Service
public class TConfInfoServiceImpl implements ITConfInfoService
{
    @Autowired
    private TConfInfoMapper tConfInfoMapper;

    /**
     * 查询会议预约信息
     *
     * @param id 会议预约信息ID
     * @return 会议预约信息
     */
    @Override
    public TConfInfo selectTConfInfoById(Long id)
    {
        return tConfInfoMapper.selectTConfInfoById(id);
    }

    /**
     * 查询会议预约信息列表
     *
     * @param tConfInfo 会议预约信息
     * @return 会议预约信息
     */
    @Override
    public List<TConfInfo> selectTConfInfoList(TConfInfo tConfInfo)
    {
        return tConfInfoMapper.selectTConfInfoList(tConfInfo);
    }

    /**
     * 新增会议预约信息
     *
     * @param tConfInfo 会议预约信息
     * @return 结果
     */
    @Override
    public int insertTConfInfo(TConfInfo tConfInfo)
    {
        return tConfInfoMapper.insertTConfInfo(tConfInfo);
    }

    /**
     * 修改会议预约信息
     *
     * @param tConfInfo 会议预约信息
     * @return 结果
     */
    @Override
    public int updateTConfInfo(TConfInfo tConfInfo)
    {
        return tConfInfoMapper.updateTConfInfo(tConfInfo);
    }

    /**
     * 批量删除会议预约信息
     *
     * @param ids 需要删除的会议预约信息ID
     * @return 结果
     */
    @Override
    public int deleteTConfInfoByIds(Long[] ids)
    {
        return tConfInfoMapper.deleteTConfInfoByIds(ids);
    }

    /**
     * 删除会议预约信息信息
     *
     * @param id 会议预约信息ID
     * @return 结果
     */
    @Override
    public int deleteTConfInfoById(Long id)
    {
        return tConfInfoMapper.deleteTConfInfoById(id);
    }
}
